@@ -3,7 +3,7 @@ import requests
 import argparse
 import pandas as pd
 
-from parsers import parse_json, parse_csv
+from usergen.parsers import parse_json, parse_csv
 
 def main(args):
 
